package
Version:
v1.10.2
Opens a new window with list of versions in this module.
Published: Jun 7, 2026
License: MIT
Opens a new window with license information.
Imports: 20
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type LogEntry struct {
Timestamp string `json:"timestamp"`
Action string `json:"action"`
Remote string `json:"remote"`
Files []string `json:"files"`
Status string `json:"status"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.